Cypress.Commands.add('typeIntoUi5Input', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('clearUi5Input', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .clear({ force: true, ...options });
});
Cypress.Commands.add('typeIntoUi5InputWithDelay', { prevSubject: 'element' }, (subject, text, delay = 500, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .wait(delay)
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('typeIntoUi5TextArea', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .shadow()
        .find('textarea')
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('toggleUi5Checkbox', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('toggleUi5Switch', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('clickUi5RadioButton', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('closeUi5PopupWithEsc', () => {
    cy.get('body').type('{esc}', { force: true });
});
Cypress.Commands.add('clickUi5ListItemByText', (text) => {
    cy.contains(text).find('li').click({ force: true });
});
Cypress.Commands.add('clickUi5SelectOptionByText', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .contains(text)
        .then(($option) => {
        $option.get(0).focus();
    })
        .click(options);
});
Cypress.Commands.add('clickUi5SelectOption', { prevSubject: 'element' }, (subject, options = {}) => {
    cy.wrap(subject).then(($option) => {
        // @ts-expect-error: cannot set $option to use OptionDomRef
        const domRef = $option.get(0).getDomRef();
        cy.wrap(domRef).click(options);
    });
});
Cypress.Commands.add('clickDropdownMenuItemByText', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject).find('[ui5-responsive-popover]').should('have.attr', 'open');
    cy.wrap(subject).then(([$dropdown]) => {
        switch (true) {
            case $dropdown.hasAttribute('ui5-select'):
                cy.wrap($dropdown).contains(text).clickDropdownMenuItem(options);
                break;
            default:
                cy.wrap($dropdown).get(`[text="${text}"]`).clickDropdownMenuItem(options);
                break;
        }
    });
});
Cypress.Commands.add('clickDropdownMenuItem', { prevSubject: 'element' }, (subject, options = {}) => {
    cy.wrap(subject).then(([$option]) => {
        const domRef = $option.getDomRef();
        cy.wrap(domRef).focus();
        if ($option.hasAttribute('ui5-option')) {
            //todo: check if this can be refactored to use `click()` again.
            cy.wrap(domRef).trigger('keydown', {
                force: true,
                ...options,
                key: 'Enter',
                code: 'Enter',
                which: 13,
                keyCode: 13
            });
        }
        else {
            cy.wrap(domRef).click(options);
        }
    });
});
Cypress.Commands.add('openDropDownByClick', { prevSubject: 'element' }, (subject, options = {}) => {
    if (subject.get(0).hasAttribute('ui5-multi-combobox')) {
        // mcb needs a lot of calculation time to make the popover available
        cy.wait(500);
    }
    cy.wrap(subject).shadow().find('.inputIcon').click(options);
});
export {};
